@@ -202,14 +202,15 @@ sn_launcher_context_initiate (SnLauncherContext *context,
     256; /* 256 is longer than a couple %d and some slashes */
   
   s = sn_malloc (len + 3);
-  snprintf (s, len, "%s/%s/%lu/%d-%d-%s",
-            canonicalized_launcher, canonicalized_launchee, (unsigned long) timestamp,
-            (int) getpid (), (int) sequence_number, hostbuf);
+  snprintf (s, len, "%s/%s/%d-%d-%s_TIME%lu",
+            canonicalized_launcher, canonicalized_launchee,
+            (int) getpid (), (int) sequence_number, hostbuf,
+            (unsigned long) timestamp);
   ++sequence_number;
   
   sn_free (canonicalized_launcher);
   sn_free (canonicalized_launchee);
-  
+
   context->startup_id = s;
   
   i = 0;
